###################################################################
#
# Morphospace time-series analysis of lamn vs. carch using the    #
# three-binning scheme #
# 
# Heterodonty test: Lateral teeth only
###################################################################

# Loop For PC1 and PC2 #

# Set margins and divide screen #
P <- layout(matrix(c(1:6),ncol = 2,byrow = FALSE))
layout.show(P)

# Global three-binning scheme
ages <- c(3,1,2)

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(levels(Lat.Lamn$Age.3)[ages[i]] == "Maastrichtian") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 1 (',round(PCA$pc.summary$importance[2,1]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  
  # Lamniformes (PC1)
  A <- hist(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],1],
            breaks = 15 ,freq = TRUE,col = scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,30),xlim = range(scores[,1]),xlab = x.lab,
            font.lab = 2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1,lwd = 2)
  axis(side = 2,lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],1],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col = scales::alpha('#E41A1C',.5),lwd = 2)
  # Compute the median of all distributions and plot
  abline(v = median(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],1],na.rm = TRUE),
         col = scales::alpha('#E41A1C',.5),lty = "dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],1],na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],1])
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI), c(max(A$counts),max(A$counts)),col = '#E41A1C')
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI),c(max(A$counts) + 0.75,max(A$counts) - 0.75),col = '#E41A1C')
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI),c(max(A$counts) + 0.75,max(A$counts) - 0.75),col = '#E41A1C')
  
  # Carcharhiniformes (PC1)
  B <- hist(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],1],add = TRUE,
            breaks = 15, col = scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,30),xlim = range(scores[,1]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],1],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col = scales::alpha('#377EB8',.25),lwd = 2)
  # Compute the median of all distributions and plot
  abline(v = median(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],1],na.rm = TRUE),
         col = scales::alpha('#377EB8',.25),lty = "dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],1],na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],1])
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI),c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI),c(max(B$counts) + 0.75,max(B$counts) - 0.75),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI),c(max(B$counts) + 0.75,max(B$counts) - 0.75),col = '#377EB8') #boundary lines
}

# %% --------------------------------------------------------------------------------- %% #

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(levels(Lat.Lamn$Age.3)[ages[i]] == "Maastrichtian") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 2 (',round(PCA$pc.summary$importance[2,2]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  
  # Lamniformes (PC2)
  A <- hist(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],2],
            breaks = 20 ,freq = TRUE,col = scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,25),xlim = range(scores[,2]),xlab = x.lab,
            font.lab = 2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1,lwd = 2)
  axis(side = 2,lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],2],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col = scales::alpha('#E41A1C',.5),lwd = 2)
  # Compute the median of all distributions and plot
  abline(v = median(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],2],na.rm = TRUE),
         col = scales::alpha('#E41A1C',.5),lty = "dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],2],na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(lamn.lateral.scores[Lat.Lamn$Age.3 == levels(Lat.Lamn$Age.3)[ages[i]],2])
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI),c(max(A$counts),max(A$counts)),col = '#E41A1C')
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI),c(max(A$counts) + 0.5,max(A$counts) - 0.5),col = '#E41A1C') #boundary lines
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI),c(max(A$counts) + 0.5,max(A$counts) - 0.5),col = '#E41A1C') #boundary lines
  
  # Carcharhiniformes (PC2)
  B <- hist(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],2],add = TRUE,
            breaks = 20, col = scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,25),xlim = range(scores[,2]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],2],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col = scales::alpha('#377EB8',.5),lwd = 2)
  # Compute the median of all distributions and plot
  abline(v = median(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],2],na.rm = TRUE),
         col = scales::alpha('#377EB8',.5),lty = "dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],2],na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(carch.lateral.scores[Lat.Carch$Age.3 == levels(Lat.Carch$Age.3)[ages[i]],2])
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI),c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI),c(max(B$counts) + 0.5,max(B$counts) - 0.5),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI),c(max(B$counts) + 0.5,max(B$counts) - 0.5),col = '#377EB8') #boundary lines
}