###########################################################
#
# Bivariate morphospace plot with marginal density curves #
# using ggplot2 and gridExtra: PC3-PC4
#
###########################################################

# Create ggplot dataframe:
x <- (scores[,3])
y <- (scores[,4])
group <- as.factor(Data$Order)
DF <- data.frame(x, y, group)

## Relevel the data:
levels(DF$group)
DF$group <- factor(DF$group, levels = rev(levels(DF$group)))
levels(DF$group)

# Plot general bivariate morphospace:
xy <- ggplot(DF,aes(x,y,col = group)) +
  scale_color_manual(values = c('#E41A1C','#377EB8')) +
  geom_point(alpha = .5) +
  xlab(paste('Principal Component 3 (',round(PCA$pc.summary$importance[2,3]*100,2),'%)',sep = "")) +
  ylab(paste('Principal Component 4 (',round(PCA$pc.summary$importance[2,4]*100,2),'%)',sep = "")) +
  theme_classic() +
  coord_cartesian(xlim = range(scores[,3]),expand = TRUE) +
  coord_cartesian(ylim = range(scores[,4]),expand = TRUE) +
  theme(axis.title = element_text(face = "bold",color = "black")) +
  geom_hline(yintercept = 0, color = "black",size = .5,linetype = 2) +
  geom_vline(xintercept = 0,color = "black",size = .5,linetype = 2) +
  theme(legend.title = element_blank(),panel.border = element_rect(colour = "black", fill = NA,size = .5))

# x-axis density plot:
xDen <- ggplot(DF, aes(x = x,fill = group,col = group)) +
  scale_fill_manual(values = c('#E41A1C','#377EB8')) + 
  geom_density(alpha = 0.5) +
  theme_classic() +
  coord_cartesian(xlim = range(scores[,3]),expand = TRUE) +
  theme(axis.title = element_text(face = "bold",color = "black")) +
  theme(legend.title = element_blank()) +
  xlab("")

# y-axis density plot:
yDen <- ggplot(DF, aes(x = y,fill = group,col = group)) +
  scale_fill_manual(values = c('#E41A1C','#377EB8')) + 
  geom_density(alpha = 0.5) +
  theme_classic() +
  coord_cartesian(xlim = range(scores[,4]),expand = TRUE) +
  theme(axis.title = element_text(face = "bold",color = "black")) +
  theme(legend.title = element_blank()) +
  xlab("") +
  coord_flip()

# Legend Function:
x_legend <- function(a.gplot){
  tmp <- ggplot_gtable(ggplot_build(a.gplot))
  leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
  legend <- tmp$grobs[[leg]]
  return(legend)
}

leg <- x_legend(xDen)

# Combine all panels to plot a scatter with marginal density plot:
grid.arrange(xDen + theme(legend.position = "none",legend.title = element_blank()),
             leg,xy + theme(legend.position = "none",legend.title = element_blank()),
             yDen + theme(legend.position ="none",legend.title = element_blank()),
             nrow = 2,ncol = 2,widths = unit(c(2,1),c("null","null")),
             heights = unit(c(1,2),c("null","null")))
