# Morphospace time-series analysis of Lamniformes vs. Carcharhiniformes using the two-bin scheme #
# Regional-level analysis

# Loop For PC1 and PC2 #

# Set margins and divide screen #
P <- layout(matrix(c(2,1,4,3),ncol = 2,byrow=FALSE))
# Regional two-binning scheme
ages <- c("late","early")

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(ages[i] == "late") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 1 (',round(PCA$pc.summary$importance[2,1]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  
  # Regional Lamniformes (PC1)
  lam.vect <- imp.data[rownames(Den.Data.2[Den.Data.2$Sub == ages[i],]),1]
  A <- hist(lam.vect,
            breaks = 15 ,freq = TRUE,col=scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,6),xlim=range(scores[,1]),xlab = x.lab,
            font.lab=2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1, lwd = 2)
  axis(side = 2, lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(lam.vect,na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#E41A1C',.5),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(lam.vect,na.rm = TRUE),
         col=scales::alpha('#E41A1C',.5),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(lam.vect,na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(lam.vect)
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI), c(max(A$counts),max(A$counts)),col = '#E41A1C')
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI), c(max(A$counts)+0.25,max(A$counts)-0.25),col = '#E41A1C')
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI), c(max(A$counts)+0.25,max(A$counts)-0.25),col = '#E41A1C')
  
  # Carcharhiniformes (PC1)
  car.vect <- imp.data.2[rownames(Den.Data.3[Den.Data.3$Sub == ages[i],]),1]
  B <- hist(car.vect,add = TRUE,
            breaks = 15, col=scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,6),xlim=range(scores[,1]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(car.vect,na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#377EB8',.25),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(car.vect,na.rm = TRUE),
         col=scales::alpha('#377EB8',.25),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(car.vect,na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(car.vect)
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI), c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI), c(max(B$counts)+0.25,max(B$counts)-0.25),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI), c(max(B$counts)+0.25,max(B$counts)-0.25),col = '#377EB8') #boundary lines
}

# %% --------------------------------------------------------------------------------- %% #

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(ages[i] == "late") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 2 (',round(PCA$pc.summary$importance[2,2]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  
  # Regional Lamniformes (PC2)
  lam.vect <- imp.data[rownames(Den.Data.2[Den.Data.2$Sub == ages[i],]),2]
  A <- hist(lam.vect,
            breaks = 15 ,freq = TRUE,col=scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,10),xlim=range(scores[,2]),xlab = x.lab,
            font.lab=2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1, lwd = 2)
  axis(side = 2, lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(lam.vect,na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#E41A1C',.5),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(lam.vect,na.rm = TRUE),
         col=scales::alpha('#E41A1C',.5),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(lam.vect,na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(lam.vect)
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI), c(max(A$counts),max(A$counts)),col = '#E41A1C')
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI), c(max(A$counts)+0.25,max(A$counts)-0.25),col = '#E41A1C')
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI), c(max(A$counts)+0.25,max(A$counts)-0.25),col = '#E41A1C')
  
  # Carcharhiniformes (PC2)
  car.vect <- imp.data.2[rownames(Den.Data.3[Den.Data.3$Sub == ages[i],]),2]
  B <- hist(car.vect,add = TRUE,
            breaks = 20, col=scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,10),xlim=range(scores[,2]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(car.vect,na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#377EB8',.25),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(car.vect,na.rm = TRUE),
         col=scales::alpha('#377EB8',.25),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(car.vect,na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(car.vect)
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI), c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI), c(max(B$counts)+0.25,max(B$counts)-0.25),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI), c(max(B$counts)+0.25,max(B$counts)-0.25),col = '#377EB8') #boundary lines
}