# Morphospace time-series analysis of lamn vs. carch using the three-bin scheme #
# Loop For PC3 and PC4 #

# Set margins and divide screen #
P <- layout(matrix(c(1:6),ncol = 2,byrow=FALSE))
layout.show(P)
# Global three-binning scheme
ages <- c(3,1,2)

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(levels(Data.2$Age.3)[ages[i]] == "Maastrichtian") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 3 (',round(PCA$pc.summary$importance[2,3]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  if(levels(Data.2$Age.3)[ages[i]] == "Thanetian") {
    breaks = 10
  }
  else {
    breaks = 20
  }
  # Lamniformes (PC1)
  A <- hist(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],3],
            breaks = breaks ,freq = TRUE,col=scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,30),xlim=range(scores[,3]),xlab = x.lab,
            font.lab=2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1, lwd = 2)
  axis(side = 2, lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],3],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#E41A1C',.5),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],3],na.rm = TRUE),
         col=scales::alpha('#E41A1C',.5),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],3],na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],3])
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI), c(max(A$counts),max(A$counts)),col = '#E41A1C')
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI), c(max(A$counts)+0.75,max(A$counts)-0.75),col = '#E41A1C')
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI), c(max(A$counts)+0.75,max(A$counts)-0.75),col = '#E41A1C')
  
  # Carcharhiniformes (PC1)
  B <- hist(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],3],add = TRUE,
            breaks = 20, col=scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,30),xlim=range(scores[,3]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],3],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#377EB8',.25),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],3],na.rm = TRUE),
         col=scales::alpha('#377EB8',.25),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],3],na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],3])
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI), c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI), c(max(B$counts)+0.75,max(B$counts)-0.75),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI), c(max(B$counts)+0.75,max(B$counts)-0.75),col = '#377EB8') #boundary lines
}

# %% --------------------------------------------------------------------------------- %% #

for(i in 1:length(ages)) {
  par(bg = "white")
  par(mar = c(4,4,1,1))
  if(levels(Data.2$Age.3)[ages[i]] == "Maastrichtian") {
    x.axt <- "s"
    x.lab <- paste('Principal Component 4 (',round(PCA$pc.summary$importance[2,4]*100,2),'%)',sep = "")
  }
  else {
    x.axt <- "n"
    x.lab <- ""
  }
  if(levels(Data.2$Age.3)[ages[i]] == "Maastrichtian" | levels(Data.2$Age.3)[ages[i]] == "DanSelCombined") {
    x = 10
  }
  else {
    x = 15
  }
  if(levels(Data.3$Age.3)[ages[i]] == "Maastrichtian") {
    y = 10
  }
  else {
    y = 15
  }
  # Lamniformes (PC2)
  A <- hist(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],4],
            breaks = x ,freq = TRUE,col=scales::alpha('#E41A1C',.5),border = '#E41A1C',
            main = NA,ylim = c(0,35),xlim=range(scores[,4]),xlab = x.lab,
            font.lab=2,xaxt = x.axt)
  # Make x and y axis lines bold
  axis(side = 1, lwd = 2)
  axis(side = 2, lwd = 2)
  # Compute and superimpose denisty cruve on histograms
  multiplier <- A$counts/A$density
  mydensity <- density(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],4],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#E41A1C',.5),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],4],na.rm = TRUE),
         col=scales::alpha('#E41A1C',.5),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],4],na.rm = TRUE),
         max(A$counts),pch = 19, col = '#E41A1C')
  # Compute confidence interval of the mean and plot
  CI.2 <- intervals(imp.data[Data.2$Age.3 == levels(Data.2$Age.3)[ages[i]],4])
  # Add boundary lines on both sides
  lines(x = c(CI.2$Lower.CI,CI.2$Upper.CI), c(max(A$counts),max(A$counts)),col = '#E41A1C')
  lines(x = c(CI.2$Lower.CI,CI.2$Lower.CI), c(max(A$counts)+0.5,max(A$counts)-0.5),col = '#E41A1C') #boundary lines
  lines(x = c(CI.2$Upper.CI,CI.2$Upper.CI), c(max(A$counts)+0.5,max(A$counts)-0.5),col = '#E41A1C') #boundary lines
  
  # Carcharhiniformes (PC2)
  B <- hist(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],4],add = TRUE,
            breaks = y, col=scales::alpha('#377EB8',.25),border = '#377EB8',
            freq = TRUE,main = NA,ylim = c(0,25),xlim=range(scores[,4]))
  # Compute and superimpose denisty cruve on histograms
  multiplier <- B$counts/B$density
  mydensity <- density(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],4],na.rm = TRUE)
  mydensity$y <- mydensity$y * multiplier[1]
  lines(x = mydensity,col=scales::alpha('#377EB8',.5),lwd=2)
  # Compute the median of all distributions and plot
  abline(v = median(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],4],na.rm = TRUE),
         col=scales::alpha('#377EB8',.5),lty ="dashed",
         lwd = 2)
  # Compute the mean of all distributions and plot
  points(mean(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],4],na.rm = TRUE),
         max(B$counts),pch = 19,col = '#377EB8')
  # Compute confidence interval of the mean and plot
  CI.3 <- intervals(imp.data.2[Data.3$Age.3 == levels(Data.3$Age.3)[ages[i]],4])
  # Add boundary lines on both sides
  lines(x = c(CI.3$Lower.CI,CI.3$Upper.CI), c(max(B$counts),max(B$counts)),col = '#377EB8')
  lines(x = c(CI.3$Lower.CI,CI.3$Lower.CI), c(max(B$counts)+0.5,max(B$counts)-0.5),col = '#377EB8') #boundary lines
  lines(x = c(CI.3$Upper.CI,CI.3$Upper.CI), c(max(B$counts)+0.5,max(B$counts)-0.5),col = '#377EB8') #boundary lines
}